@@ -38,11 +38,8 @@ def arg_parser():
     parser.add_argument('-p', "--path", type=str, help="upload file absolute path")
 
     args = parser.parse_args()
-    config = yaml_parser.parse_config()
-    config_file_path = yaml_parser.get_config_path()
-    # print which config file is being used and the path
-    logger.log(message="Using config file: " + config_file_path, log_level="info", to_file=True, to_terminal=True)
-    logger.log(message="Using config file: " + config_file_path, log_level="info", to_file=True, to_terminal=True)
+    config, file = yaml_parser.parse_config()
+    logger.log(message="Config file: " + file + 'found at absolute path: ' + os.path.abspath(file), log_level="info", to_file=True, to_terminal=True)
     logger.log(message="Starting Robin Radar Systems Software Uploader", log_level="info", to_file=True, to_terminal=True)
     logger.log(message="Version: " + _version.__version__, log_level="info", to_file=True, to_terminal=True)
     logger.log(message="Username: " + config['robin_email'], log_level="info", to_file=True, to_terminal=True)
