@@ -35,10 +35,6 @@ def check_and_ask(config):
                 check_and_ask(config[key])
 
 
-# function for return config file path
-def get_config_path(config_file):
-    return os.path.abspath(config_file)
-
 def parse_config():
     config_files = [
         os.path.join(os.path.expanduser("/opt/robin/config/sd-upload"), "sd-upload-config.yml"),
@@ -58,7 +54,6 @@ def parse_config():
             with open(cfg_file, 'r') as config_file:
                 config = yaml.safe_load(config_file)
                 file = cfg_file
-                get_config_path(file)
                 # print(f"Config {cfg_file} found at full path {os.path.abspath(cfg_file)}")
                 break
     if not config:
@@ -78,4 +73,4 @@ def parse_config():
     except (OSError, yaml.parser.ParserError, yaml.scanner.ScannerError) as e:
         print(f"Error: Failed to write config file. {e}")
 
-    return config
+    return config, file
